def PrintMeshInfo(msh):
     #aMesh = theMesh.GetMesh()
     print "mesh information:"
     print "Number of nodes       : ", msh.NbNodes()
     print "Number of edges       : ", msh.NbEdges()
     print "Number of faces       : ", msh.NbFaces()
     print "Number of volumes     : ", msh.NbVolumes()


##import Numeric
##import string, os, sys, re
##sys.path.insert( 0, os.path.dirname(__file__) )
##exec("from "+re.sub("SMESH$","GEOM",__name__)+" import *")




import geompy
import SALOMEDS
import salome
import smesh

import StdMeshers
import NETGENPlugin

from SMESH import *
from StdMeshers import *


## import GEOM dump file ## 
import string, os, sys, re


zeta = 0.5   
zetam1 = 1-zeta
Bx = 3
By = 8
Bz = 23
block = geompy.MakeBoxDXDYDZ(Bx,By,Bz)


block26 = geompy.GetSubShape(block, [26])
p1star = geompy.MakeVertexOnCurve(block26,zeta)
block30 = geompy.GetSubShape(block, [30])
p2star = geompy.MakeVertexOnCurve(block30,zetam1)

# to be used in the mesher
x1,y1,z1 = geompy.PointCoordinates(p1star)
x2,y2,z2 = geompy.PointCoordinates(p2star)

DZplus = 17.0
DZmin  = 0.0 # create overlap of shell into volume block (For arlequin only)


p1 = geompy.MakeVertexWithRef(p1star, 0, 0, -DZmin)
p2 = geompy.MakeVertexWithRef(p2star, 0, 0, -DZmin)
p3 = geompy.MakeVertexWithRef(p2star, 0, 0, DZplus)
p4 = geompy.MakeVertexWithRef(p1star, 0, 0, DZplus)

line1 = geompy.MakeLineTwoPnt(p1, p4)
line2 = geompy.MakeLineTwoPnt(p4, p3)
line3 = geompy.MakeLineTwoPnt(p3, p2)
line4 = geompy.MakeLineTwoPnt(p2, p1)
face1 = geompy.MakeFaceWires([line1, line2, line3, line4], 1)


# create groups (Faces) at top  and bottom of block
FBbot = geompy.CreateGroup(block, geompy.ShapeType["FACE"])
geompy.UnionIDs(FBbot, [31])
block = geompy.GetMainShape(FBbot)
FBtop = geompy.CreateGroup(block, geompy.ShapeType["FACE"])
geompy.UnionIDs(FBtop, [33])
block = geompy.GetMainShape(FBtop)


# create groups (edges) at top and bottom of face1
EFbot = geompy.CreateGroup(face1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(EFbot, [6])
face1 = geompy.GetMainShape(EFbot)
EFtop = geompy.CreateGroup(face1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(EFtop, [10])
face1 = geompy.GetMainShape(EFtop)

# create groups (shell and node) on faces face1-2
shell = geompy.CreateGroup(face1, geompy.ShapeType["FACE"])
geompy.UnionIDs(shell, [1])
face1 = geompy.GetMainShape(shell)

# make entities visible
geompy.addToStudy( p1, "p1" )
geompy.addToStudy( p2, "p2" )
geompy.addToStudy( p3, "p3" )
geompy.addToStudy( p4, "p4" )

geompy.addToStudy( line1, "line1" )
geompy.addToStudy( line2, "line2" )
geompy.addToStudy( line3, "line3" )
geompy.addToStudy( line4, "line4" )


# create compounds of constr <-- face1 and blcok
constr = geompy.MakeCompound([face1, block])

# define group on constr
Cline = geompy.CreateGroup(constr, geompy.ShapeType["EDGE"])
geompy.UnionIDs(Cline, [7])
constr = geompy.GetMainShape(Cline)
Ctop = geompy.CreateGroup(constr, geompy.ShapeType["FACE"])
geompy.UnionIDs(Ctop, [44])
constr = geompy.GetMainShape(Ctop)
Cbot = geompy.CreateGroup(constr, geompy.ShapeType["FACE"])
geompy.UnionIDs(Cbot, [42])
constr = geompy.GetMainShape(Cbot)

Nforce = geompy.CreateGroup(constr, geompy.ShapeType["VERTEX"])
geompy.UnionIDs(Nforce, [5, 10])
constr = geompy.GetMainShape(Nforce)


geompy.addToStudy( constr, "constr" )
geompy.addToStudy( face1, "face1" )
geompy.addToStudy( block, "block" )

geompy.addToStudyInFather(constr,block, "block" )
geompy.addToStudyInFather(constr,shell, "shell" )
geompy.addToStudyInFather(constr,FBtop, "FBtop" )
geompy.addToStudyInFather(constr,FBbot, "FBbot" )
geompy.addToStudyInFather(constr,Ctop, "Ctop" )
geompy.addToStudyInFather(constr,Cbot, "Cbot" )
geompy.addToStudyInFather(constr,Cline, "Cline" )
geompy.addToStudyInFather(constr,Nforce, "Nforce" )


### ============
### start mesher
### ============

constr = smesh.Mesh(constr)
NETGEN_3D_Parameters = smesh.CreateHypothesis('NETGEN_Parameters', 'NETGENEngine')
NETGEN_3D_Parameters.SetMaxSize( 0.4 )
NETGEN_3D_Parameters.SetSecondOrder( 1 )
NETGEN_3D_Parameters.SetOptimize( 1 )
NETGEN_3D_Parameters.SetFineness( 3 )
Max_Size3D = smesh.CreateHypothesis('MaxLength')
Max_Size3D.SetLength( 1.0 )
Regular1D = constr.Segment()
Automatic_length = Regular1D.AutomaticLength(0.6)  ## decrease for testing with coarser mesh, eg 0.2
Quadratic_Mesh = Regular1D.QuadraticMesh()
MEFISTO_2D = constr.Triangle()
Tetrahedron_Netgen = constr.Tetrahedron(algo=smesh.NETGEN)
isDone = constr.Compute()


###=====================================
### add groups to mesh for loads, bc, materialprops
block = constr.Group(block)
shell = constr.Group(shell)
FBbot = constr.Group(FBbot)
FBtop = constr.Group(FBtop)
Nforce = constr.Group(Nforce)
Cline = constr.Group(Cline)



## set object names
smesh.SetName(constr.GetMesh(), 'constr')
smesh.SetName(NETGEN_3D_Parameters, 'NETGEN 3D Parameters')
smesh.SetName(Max_Size3D, 'Max Size 3D')
smesh.SetName(Regular1D.GetAlgorithm(), 'Regular 1D')
smesh.SetName(Automatic_length, 'Automatic length')
smesh.SetName(Quadratic_Mesh, 'QuadraticMesh')
smesh.SetName(MEFISTO_2D.GetAlgorithm(), 'MEFISTO_2D')
smesh.SetName(Tetrahedron_Netgen.GetAlgorithm(), 'Tetrahedron (Netgen)')

smesh.SetName(block, 'block')
smesh.SetName(shell, 'shell')
smesh.SetName(FBbot, 'FBbot')
smesh.SetName(FBtop, 'FBtop')
smesh.SetName(Nforce, 'Nforce')
smesh.SetName(Cline, 'Cline')

PrintMeshInfo(constr)


## import GEOM dump file ## 


### you might have to change this to your own path:
### constr.ExportMED('<path>/coq3dconstr.med', 0, SMESH.MED_V2_2, 1 )
### constr.ExportMED('./coq3dconstr.med', 0, SMESH.MED_V2_2, 1 )
### constr.ExportMED('./coq3dconstr.med', 0, MED_V2_2, 1 )
constr.ExportMED('/cae/caexample/shell_solid/solidshell/V02_coqmassive_coque3d//coq3dconstr2.med')




